# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.4.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKRegionGrowingPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if getattr(globals().get("__spec__"), "parent", None) or __package__ or "." in __name__:
    from . import _itkIsolatedConnectedImageFilterPython
else:
    import _itkIsolatedConnectedImageFilterPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.itkImageToImageFilterAPython
import itk.itkVectorImagePython
import itk.itkIndexPython
import itk.itkSizePython
import itk.pyBasePython
import itk.itkOffsetPython
import itk.itkVariableLengthVectorPython
import itk.stdcomplexPython
import itk.ITKCommonBasePython
import itk.itkMatrixPython
import itk.vnl_vectorPython
import itk.vnl_matrixPython
import itk.vnl_matrix_fixedPython
import itk.itkCovariantVectorPython
import itk.itkFixedArrayPython
import itk.vnl_vector_refPython
import itk.itkVectorPython
import itk.itkPointPython
import itk.itkImagePython
import itk.itkRGBAPixelPython
import itk.itkRGBPixelPython
import itk.itkSymmetricSecondRankTensorPython
import itk.itkImageRegionPython
import itk.itkImageToImageFilterCommonPython
import itk.itkImageSourcePython
import itk.itkImageSourceCommonPython
import itk.itkPhasedArray3DSpecialCoordinatesImagePython

def itkIsolatedConnectedImageFilterIF2IF2_New():
    return itkIsolatedConnectedImageFilterIF2IF2.New()

class itkIsolatedConnectedImageFilterIF2IF2(itk.itkImageToImageFilterAPython.itkImageToImageFilterIF2IF2):
    r"""Proxy of C++ itkIsolatedConnectedImageFilterIF2IF2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkIsolatedConnectedImageFilterIF2IF2_Pointer"""
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIF2IF2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkIsolatedConnectedImageFilterIF2IF2_Pointer"""
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIF2IF2_Clone(self)

    def PrintSelf(self, os, indent):
        r"""
        PrintSelf(self, os, indent)

        Parameters
        ----------
        os: std::basic_ostream< char,std::char_traits< char > > &
        indent: itkIndent

        """
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIF2IF2_PrintSelf(self, os, indent)

    def AddSeed1(self, seed):
        r"""
        AddSeed1(self, seed)

        Parameters
        ----------
        seed: itkIndex2 const &

        """
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIF2IF2_AddSeed1(self, seed)

    def SetSeed1(self, seed):
        r"""
        SetSeed1(self, seed)

        Parameters
        ----------
        seed: itkIndex2 const &

        """
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIF2IF2_SetSeed1(self, seed)

    def ClearSeeds1(self):
        r"""ClearSeeds1(self)"""
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIF2IF2_ClearSeeds1(self)

    def AddSeed2(self, seed):
        r"""
        AddSeed2(self, seed)

        Parameters
        ----------
        seed: itkIndex2 const &

        """
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIF2IF2_AddSeed2(self, seed)

    def SetSeed2(self, seed):
        r"""
        SetSeed2(self, seed)

        Parameters
        ----------
        seed: itkIndex2 const &

        """
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIF2IF2_SetSeed2(self, seed)

    def ClearSeeds2(self):
        r"""ClearSeeds2(self)"""
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIF2IF2_ClearSeeds2(self)

    def GetSeeds1(self):
        r"""GetSeeds1(self) -> std::vector< itkIndex2,std::allocator< itkIndex2 > > const &"""
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIF2IF2_GetSeeds1(self)

    def GetSeeds2(self):
        r"""GetSeeds2(self) -> std::vector< itkIndex2,std::allocator< itkIndex2 > > const &"""
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIF2IF2_GetSeeds2(self)

    def SetLower(self, _arg):
        r"""
        SetLower(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIF2IF2_SetLower(self, _arg)

    def GetLower(self):
        r"""GetLower(self) -> float const &"""
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIF2IF2_GetLower(self)

    def SetUpper(self, _arg):
        r"""
        SetUpper(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIF2IF2_SetUpper(self, _arg)

    def GetUpper(self):
        r"""GetUpper(self) -> float const &"""
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIF2IF2_GetUpper(self)

    def SetIsolatedValueTolerance(self, _arg):
        r"""
        SetIsolatedValueTolerance(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIF2IF2_SetIsolatedValueTolerance(self, _arg)

    def GetIsolatedValueTolerance(self):
        r"""GetIsolatedValueTolerance(self) -> float const &"""
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIF2IF2_GetIsolatedValueTolerance(self)

    def SetReplaceValue(self, _arg):
        r"""
        SetReplaceValue(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIF2IF2_SetReplaceValue(self, _arg)

    def GetReplaceValue(self):
        r"""GetReplaceValue(self) -> float const &"""
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIF2IF2_GetReplaceValue(self)

    def GetIsolatedValue(self):
        r"""GetIsolatedValue(self) -> float const &"""
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIF2IF2_GetIsolatedValue(self)

    def SetFindUpperThreshold(self, _arg):
        r"""
        SetFindUpperThreshold(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIF2IF2_SetFindUpperThreshold(self, _arg)

    def FindUpperThresholdOn(self):
        r"""FindUpperThresholdOn(self)"""
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIF2IF2_FindUpperThresholdOn(self)

    def FindUpperThresholdOff(self):
        r"""FindUpperThresholdOff(self)"""
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIF2IF2_FindUpperThresholdOff(self)

    def GetFindUpperThreshold(self):
        r"""GetFindUpperThreshold(self) -> bool const &"""
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIF2IF2_GetFindUpperThreshold(self)

    def GetThresholdingFailed(self):
        r"""GetThresholdingFailed(self) -> bool const &"""
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIF2IF2_GetThresholdingFailed(self)
    InputHasNumericTraitsCheck = _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIF2IF2_InputHasNumericTraitsCheck
    
    __swig_destroy__ = _itkIsolatedConnectedImageFilterPython.delete_itkIsolatedConnectedImageFilterIF2IF2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkIsolatedConnectedImageFilterIF2IF2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIF2IF2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkIsolatedConnectedImageFilterIF2IF2

        Create a new object of the class itkIsolatedConnectedImageFilterIF2IF2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkIsolatedConnectedImageFilterIF2IF2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkIsolatedConnectedImageFilterIF2IF2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkIsolatedConnectedImageFilterIF2IF2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkIsolatedConnectedImageFilterIF2IF2 in _itkIsolatedConnectedImageFilterPython:
_itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIF2IF2_swigregister(itkIsolatedConnectedImageFilterIF2IF2)

def itkIsolatedConnectedImageFilterIF3IF3_New():
    return itkIsolatedConnectedImageFilterIF3IF3.New()

class itkIsolatedConnectedImageFilterIF3IF3(itk.itkImageToImageFilterAPython.itkImageToImageFilterIF3IF3):
    r"""Proxy of C++ itkIsolatedConnectedImageFilterIF3IF3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkIsolatedConnectedImageFilterIF3IF3_Pointer"""
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIF3IF3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkIsolatedConnectedImageFilterIF3IF3_Pointer"""
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIF3IF3_Clone(self)

    def PrintSelf(self, os, indent):
        r"""
        PrintSelf(self, os, indent)

        Parameters
        ----------
        os: std::basic_ostream< char,std::char_traits< char > > &
        indent: itkIndent

        """
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIF3IF3_PrintSelf(self, os, indent)

    def AddSeed1(self, seed):
        r"""
        AddSeed1(self, seed)

        Parameters
        ----------
        seed: itkIndex3 const &

        """
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIF3IF3_AddSeed1(self, seed)

    def SetSeed1(self, seed):
        r"""
        SetSeed1(self, seed)

        Parameters
        ----------
        seed: itkIndex3 const &

        """
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIF3IF3_SetSeed1(self, seed)

    def ClearSeeds1(self):
        r"""ClearSeeds1(self)"""
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIF3IF3_ClearSeeds1(self)

    def AddSeed2(self, seed):
        r"""
        AddSeed2(self, seed)

        Parameters
        ----------
        seed: itkIndex3 const &

        """
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIF3IF3_AddSeed2(self, seed)

    def SetSeed2(self, seed):
        r"""
        SetSeed2(self, seed)

        Parameters
        ----------
        seed: itkIndex3 const &

        """
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIF3IF3_SetSeed2(self, seed)

    def ClearSeeds2(self):
        r"""ClearSeeds2(self)"""
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIF3IF3_ClearSeeds2(self)

    def GetSeeds1(self):
        r"""GetSeeds1(self) -> std::vector< itkIndex3,std::allocator< itkIndex3 > > const &"""
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIF3IF3_GetSeeds1(self)

    def GetSeeds2(self):
        r"""GetSeeds2(self) -> std::vector< itkIndex3,std::allocator< itkIndex3 > > const &"""
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIF3IF3_GetSeeds2(self)

    def SetLower(self, _arg):
        r"""
        SetLower(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIF3IF3_SetLower(self, _arg)

    def GetLower(self):
        r"""GetLower(self) -> float const &"""
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIF3IF3_GetLower(self)

    def SetUpper(self, _arg):
        r"""
        SetUpper(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIF3IF3_SetUpper(self, _arg)

    def GetUpper(self):
        r"""GetUpper(self) -> float const &"""
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIF3IF3_GetUpper(self)

    def SetIsolatedValueTolerance(self, _arg):
        r"""
        SetIsolatedValueTolerance(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIF3IF3_SetIsolatedValueTolerance(self, _arg)

    def GetIsolatedValueTolerance(self):
        r"""GetIsolatedValueTolerance(self) -> float const &"""
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIF3IF3_GetIsolatedValueTolerance(self)

    def SetReplaceValue(self, _arg):
        r"""
        SetReplaceValue(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIF3IF3_SetReplaceValue(self, _arg)

    def GetReplaceValue(self):
        r"""GetReplaceValue(self) -> float const &"""
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIF3IF3_GetReplaceValue(self)

    def GetIsolatedValue(self):
        r"""GetIsolatedValue(self) -> float const &"""
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIF3IF3_GetIsolatedValue(self)

    def SetFindUpperThreshold(self, _arg):
        r"""
        SetFindUpperThreshold(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIF3IF3_SetFindUpperThreshold(self, _arg)

    def FindUpperThresholdOn(self):
        r"""FindUpperThresholdOn(self)"""
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIF3IF3_FindUpperThresholdOn(self)

    def FindUpperThresholdOff(self):
        r"""FindUpperThresholdOff(self)"""
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIF3IF3_FindUpperThresholdOff(self)

    def GetFindUpperThreshold(self):
        r"""GetFindUpperThreshold(self) -> bool const &"""
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIF3IF3_GetFindUpperThreshold(self)

    def GetThresholdingFailed(self):
        r"""GetThresholdingFailed(self) -> bool const &"""
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIF3IF3_GetThresholdingFailed(self)
    InputHasNumericTraitsCheck = _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIF3IF3_InputHasNumericTraitsCheck
    
    __swig_destroy__ = _itkIsolatedConnectedImageFilterPython.delete_itkIsolatedConnectedImageFilterIF3IF3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkIsolatedConnectedImageFilterIF3IF3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIF3IF3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkIsolatedConnectedImageFilterIF3IF3

        Create a new object of the class itkIsolatedConnectedImageFilterIF3IF3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkIsolatedConnectedImageFilterIF3IF3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkIsolatedConnectedImageFilterIF3IF3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkIsolatedConnectedImageFilterIF3IF3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkIsolatedConnectedImageFilterIF3IF3 in _itkIsolatedConnectedImageFilterPython:
_itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIF3IF3_swigregister(itkIsolatedConnectedImageFilterIF3IF3)

def itkIsolatedConnectedImageFilterISS2ISS2_New():
    return itkIsolatedConnectedImageFilterISS2ISS2.New()

class itkIsolatedConnectedImageFilterISS2ISS2(itk.itkImageToImageFilterAPython.itkImageToImageFilterISS2ISS2):
    r"""Proxy of C++ itkIsolatedConnectedImageFilterISS2ISS2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkIsolatedConnectedImageFilterISS2ISS2_Pointer"""
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterISS2ISS2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkIsolatedConnectedImageFilterISS2ISS2_Pointer"""
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterISS2ISS2_Clone(self)

    def PrintSelf(self, os, indent):
        r"""
        PrintSelf(self, os, indent)

        Parameters
        ----------
        os: std::basic_ostream< char,std::char_traits< char > > &
        indent: itkIndent

        """
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterISS2ISS2_PrintSelf(self, os, indent)

    def AddSeed1(self, seed):
        r"""
        AddSeed1(self, seed)

        Parameters
        ----------
        seed: itkIndex2 const &

        """
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterISS2ISS2_AddSeed1(self, seed)

    def SetSeed1(self, seed):
        r"""
        SetSeed1(self, seed)

        Parameters
        ----------
        seed: itkIndex2 const &

        """
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterISS2ISS2_SetSeed1(self, seed)

    def ClearSeeds1(self):
        r"""ClearSeeds1(self)"""
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterISS2ISS2_ClearSeeds1(self)

    def AddSeed2(self, seed):
        r"""
        AddSeed2(self, seed)

        Parameters
        ----------
        seed: itkIndex2 const &

        """
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterISS2ISS2_AddSeed2(self, seed)

    def SetSeed2(self, seed):
        r"""
        SetSeed2(self, seed)

        Parameters
        ----------
        seed: itkIndex2 const &

        """
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterISS2ISS2_SetSeed2(self, seed)

    def ClearSeeds2(self):
        r"""ClearSeeds2(self)"""
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterISS2ISS2_ClearSeeds2(self)

    def GetSeeds1(self):
        r"""GetSeeds1(self) -> std::vector< itkIndex2,std::allocator< itkIndex2 > > const &"""
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterISS2ISS2_GetSeeds1(self)

    def GetSeeds2(self):
        r"""GetSeeds2(self) -> std::vector< itkIndex2,std::allocator< itkIndex2 > > const &"""
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterISS2ISS2_GetSeeds2(self)

    def SetLower(self, _arg):
        r"""
        SetLower(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterISS2ISS2_SetLower(self, _arg)

    def GetLower(self):
        r"""GetLower(self) -> short const &"""
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterISS2ISS2_GetLower(self)

    def SetUpper(self, _arg):
        r"""
        SetUpper(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterISS2ISS2_SetUpper(self, _arg)

    def GetUpper(self):
        r"""GetUpper(self) -> short const &"""
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterISS2ISS2_GetUpper(self)

    def SetIsolatedValueTolerance(self, _arg):
        r"""
        SetIsolatedValueTolerance(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterISS2ISS2_SetIsolatedValueTolerance(self, _arg)

    def GetIsolatedValueTolerance(self):
        r"""GetIsolatedValueTolerance(self) -> short const &"""
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterISS2ISS2_GetIsolatedValueTolerance(self)

    def SetReplaceValue(self, _arg):
        r"""
        SetReplaceValue(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterISS2ISS2_SetReplaceValue(self, _arg)

    def GetReplaceValue(self):
        r"""GetReplaceValue(self) -> short const &"""
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterISS2ISS2_GetReplaceValue(self)

    def GetIsolatedValue(self):
        r"""GetIsolatedValue(self) -> short const &"""
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterISS2ISS2_GetIsolatedValue(self)

    def SetFindUpperThreshold(self, _arg):
        r"""
        SetFindUpperThreshold(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterISS2ISS2_SetFindUpperThreshold(self, _arg)

    def FindUpperThresholdOn(self):
        r"""FindUpperThresholdOn(self)"""
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterISS2ISS2_FindUpperThresholdOn(self)

    def FindUpperThresholdOff(self):
        r"""FindUpperThresholdOff(self)"""
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterISS2ISS2_FindUpperThresholdOff(self)

    def GetFindUpperThreshold(self):
        r"""GetFindUpperThreshold(self) -> bool const &"""
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterISS2ISS2_GetFindUpperThreshold(self)

    def GetThresholdingFailed(self):
        r"""GetThresholdingFailed(self) -> bool const &"""
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterISS2ISS2_GetThresholdingFailed(self)
    InputHasNumericTraitsCheck = _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterISS2ISS2_InputHasNumericTraitsCheck
    
    __swig_destroy__ = _itkIsolatedConnectedImageFilterPython.delete_itkIsolatedConnectedImageFilterISS2ISS2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkIsolatedConnectedImageFilterISS2ISS2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterISS2ISS2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkIsolatedConnectedImageFilterISS2ISS2

        Create a new object of the class itkIsolatedConnectedImageFilterISS2ISS2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkIsolatedConnectedImageFilterISS2ISS2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkIsolatedConnectedImageFilterISS2ISS2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkIsolatedConnectedImageFilterISS2ISS2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkIsolatedConnectedImageFilterISS2ISS2 in _itkIsolatedConnectedImageFilterPython:
_itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterISS2ISS2_swigregister(itkIsolatedConnectedImageFilterISS2ISS2)

def itkIsolatedConnectedImageFilterISS3ISS3_New():
    return itkIsolatedConnectedImageFilterISS3ISS3.New()

class itkIsolatedConnectedImageFilterISS3ISS3(itk.itkImageToImageFilterAPython.itkImageToImageFilterISS3ISS3):
    r"""Proxy of C++ itkIsolatedConnectedImageFilterISS3ISS3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkIsolatedConnectedImageFilterISS3ISS3_Pointer"""
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterISS3ISS3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkIsolatedConnectedImageFilterISS3ISS3_Pointer"""
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterISS3ISS3_Clone(self)

    def PrintSelf(self, os, indent):
        r"""
        PrintSelf(self, os, indent)

        Parameters
        ----------
        os: std::basic_ostream< char,std::char_traits< char > > &
        indent: itkIndent

        """
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterISS3ISS3_PrintSelf(self, os, indent)

    def AddSeed1(self, seed):
        r"""
        AddSeed1(self, seed)

        Parameters
        ----------
        seed: itkIndex3 const &

        """
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterISS3ISS3_AddSeed1(self, seed)

    def SetSeed1(self, seed):
        r"""
        SetSeed1(self, seed)

        Parameters
        ----------
        seed: itkIndex3 const &

        """
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterISS3ISS3_SetSeed1(self, seed)

    def ClearSeeds1(self):
        r"""ClearSeeds1(self)"""
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterISS3ISS3_ClearSeeds1(self)

    def AddSeed2(self, seed):
        r"""
        AddSeed2(self, seed)

        Parameters
        ----------
        seed: itkIndex3 const &

        """
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterISS3ISS3_AddSeed2(self, seed)

    def SetSeed2(self, seed):
        r"""
        SetSeed2(self, seed)

        Parameters
        ----------
        seed: itkIndex3 const &

        """
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterISS3ISS3_SetSeed2(self, seed)

    def ClearSeeds2(self):
        r"""ClearSeeds2(self)"""
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterISS3ISS3_ClearSeeds2(self)

    def GetSeeds1(self):
        r"""GetSeeds1(self) -> std::vector< itkIndex3,std::allocator< itkIndex3 > > const &"""
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterISS3ISS3_GetSeeds1(self)

    def GetSeeds2(self):
        r"""GetSeeds2(self) -> std::vector< itkIndex3,std::allocator< itkIndex3 > > const &"""
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterISS3ISS3_GetSeeds2(self)

    def SetLower(self, _arg):
        r"""
        SetLower(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterISS3ISS3_SetLower(self, _arg)

    def GetLower(self):
        r"""GetLower(self) -> short const &"""
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterISS3ISS3_GetLower(self)

    def SetUpper(self, _arg):
        r"""
        SetUpper(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterISS3ISS3_SetUpper(self, _arg)

    def GetUpper(self):
        r"""GetUpper(self) -> short const &"""
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterISS3ISS3_GetUpper(self)

    def SetIsolatedValueTolerance(self, _arg):
        r"""
        SetIsolatedValueTolerance(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterISS3ISS3_SetIsolatedValueTolerance(self, _arg)

    def GetIsolatedValueTolerance(self):
        r"""GetIsolatedValueTolerance(self) -> short const &"""
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterISS3ISS3_GetIsolatedValueTolerance(self)

    def SetReplaceValue(self, _arg):
        r"""
        SetReplaceValue(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterISS3ISS3_SetReplaceValue(self, _arg)

    def GetReplaceValue(self):
        r"""GetReplaceValue(self) -> short const &"""
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterISS3ISS3_GetReplaceValue(self)

    def GetIsolatedValue(self):
        r"""GetIsolatedValue(self) -> short const &"""
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterISS3ISS3_GetIsolatedValue(self)

    def SetFindUpperThreshold(self, _arg):
        r"""
        SetFindUpperThreshold(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterISS3ISS3_SetFindUpperThreshold(self, _arg)

    def FindUpperThresholdOn(self):
        r"""FindUpperThresholdOn(self)"""
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterISS3ISS3_FindUpperThresholdOn(self)

    def FindUpperThresholdOff(self):
        r"""FindUpperThresholdOff(self)"""
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterISS3ISS3_FindUpperThresholdOff(self)

    def GetFindUpperThreshold(self):
        r"""GetFindUpperThreshold(self) -> bool const &"""
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterISS3ISS3_GetFindUpperThreshold(self)

    def GetThresholdingFailed(self):
        r"""GetThresholdingFailed(self) -> bool const &"""
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterISS3ISS3_GetThresholdingFailed(self)
    InputHasNumericTraitsCheck = _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterISS3ISS3_InputHasNumericTraitsCheck
    
    __swig_destroy__ = _itkIsolatedConnectedImageFilterPython.delete_itkIsolatedConnectedImageFilterISS3ISS3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkIsolatedConnectedImageFilterISS3ISS3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterISS3ISS3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkIsolatedConnectedImageFilterISS3ISS3

        Create a new object of the class itkIsolatedConnectedImageFilterISS3ISS3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkIsolatedConnectedImageFilterISS3ISS3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkIsolatedConnectedImageFilterISS3ISS3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkIsolatedConnectedImageFilterISS3ISS3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkIsolatedConnectedImageFilterISS3ISS3 in _itkIsolatedConnectedImageFilterPython:
_itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterISS3ISS3_swigregister(itkIsolatedConnectedImageFilterISS3ISS3)

def itkIsolatedConnectedImageFilterIUC2IUC2_New():
    return itkIsolatedConnectedImageFilterIUC2IUC2.New()

class itkIsolatedConnectedImageFilterIUC2IUC2(itk.itkImageToImageFilterAPython.itkImageToImageFilterIUC2IUC2):
    r"""Proxy of C++ itkIsolatedConnectedImageFilterIUC2IUC2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkIsolatedConnectedImageFilterIUC2IUC2_Pointer"""
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIUC2IUC2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkIsolatedConnectedImageFilterIUC2IUC2_Pointer"""
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIUC2IUC2_Clone(self)

    def PrintSelf(self, os, indent):
        r"""
        PrintSelf(self, os, indent)

        Parameters
        ----------
        os: std::basic_ostream< char,std::char_traits< char > > &
        indent: itkIndent

        """
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIUC2IUC2_PrintSelf(self, os, indent)

    def AddSeed1(self, seed):
        r"""
        AddSeed1(self, seed)

        Parameters
        ----------
        seed: itkIndex2 const &

        """
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIUC2IUC2_AddSeed1(self, seed)

    def SetSeed1(self, seed):
        r"""
        SetSeed1(self, seed)

        Parameters
        ----------
        seed: itkIndex2 const &

        """
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIUC2IUC2_SetSeed1(self, seed)

    def ClearSeeds1(self):
        r"""ClearSeeds1(self)"""
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIUC2IUC2_ClearSeeds1(self)

    def AddSeed2(self, seed):
        r"""
        AddSeed2(self, seed)

        Parameters
        ----------
        seed: itkIndex2 const &

        """
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIUC2IUC2_AddSeed2(self, seed)

    def SetSeed2(self, seed):
        r"""
        SetSeed2(self, seed)

        Parameters
        ----------
        seed: itkIndex2 const &

        """
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIUC2IUC2_SetSeed2(self, seed)

    def ClearSeeds2(self):
        r"""ClearSeeds2(self)"""
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIUC2IUC2_ClearSeeds2(self)

    def GetSeeds1(self):
        r"""GetSeeds1(self) -> std::vector< itkIndex2,std::allocator< itkIndex2 > > const &"""
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIUC2IUC2_GetSeeds1(self)

    def GetSeeds2(self):
        r"""GetSeeds2(self) -> std::vector< itkIndex2,std::allocator< itkIndex2 > > const &"""
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIUC2IUC2_GetSeeds2(self)

    def SetLower(self, _arg):
        r"""
        SetLower(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIUC2IUC2_SetLower(self, _arg)

    def GetLower(self):
        r"""GetLower(self) -> unsigned char const &"""
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIUC2IUC2_GetLower(self)

    def SetUpper(self, _arg):
        r"""
        SetUpper(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIUC2IUC2_SetUpper(self, _arg)

    def GetUpper(self):
        r"""GetUpper(self) -> unsigned char const &"""
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIUC2IUC2_GetUpper(self)

    def SetIsolatedValueTolerance(self, _arg):
        r"""
        SetIsolatedValueTolerance(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIUC2IUC2_SetIsolatedValueTolerance(self, _arg)

    def GetIsolatedValueTolerance(self):
        r"""GetIsolatedValueTolerance(self) -> unsigned char const &"""
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIUC2IUC2_GetIsolatedValueTolerance(self)

    def SetReplaceValue(self, _arg):
        r"""
        SetReplaceValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIUC2IUC2_SetReplaceValue(self, _arg)

    def GetReplaceValue(self):
        r"""GetReplaceValue(self) -> unsigned char const &"""
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIUC2IUC2_GetReplaceValue(self)

    def GetIsolatedValue(self):
        r"""GetIsolatedValue(self) -> unsigned char const &"""
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIUC2IUC2_GetIsolatedValue(self)

    def SetFindUpperThreshold(self, _arg):
        r"""
        SetFindUpperThreshold(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIUC2IUC2_SetFindUpperThreshold(self, _arg)

    def FindUpperThresholdOn(self):
        r"""FindUpperThresholdOn(self)"""
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIUC2IUC2_FindUpperThresholdOn(self)

    def FindUpperThresholdOff(self):
        r"""FindUpperThresholdOff(self)"""
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIUC2IUC2_FindUpperThresholdOff(self)

    def GetFindUpperThreshold(self):
        r"""GetFindUpperThreshold(self) -> bool const &"""
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIUC2IUC2_GetFindUpperThreshold(self)

    def GetThresholdingFailed(self):
        r"""GetThresholdingFailed(self) -> bool const &"""
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIUC2IUC2_GetThresholdingFailed(self)
    InputHasNumericTraitsCheck = _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIUC2IUC2_InputHasNumericTraitsCheck
    
    __swig_destroy__ = _itkIsolatedConnectedImageFilterPython.delete_itkIsolatedConnectedImageFilterIUC2IUC2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkIsolatedConnectedImageFilterIUC2IUC2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIUC2IUC2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkIsolatedConnectedImageFilterIUC2IUC2

        Create a new object of the class itkIsolatedConnectedImageFilterIUC2IUC2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkIsolatedConnectedImageFilterIUC2IUC2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkIsolatedConnectedImageFilterIUC2IUC2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkIsolatedConnectedImageFilterIUC2IUC2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkIsolatedConnectedImageFilterIUC2IUC2 in _itkIsolatedConnectedImageFilterPython:
_itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIUC2IUC2_swigregister(itkIsolatedConnectedImageFilterIUC2IUC2)

def itkIsolatedConnectedImageFilterIUC3IUC3_New():
    return itkIsolatedConnectedImageFilterIUC3IUC3.New()

class itkIsolatedConnectedImageFilterIUC3IUC3(itk.itkImageToImageFilterAPython.itkImageToImageFilterIUC3IUC3):
    r"""Proxy of C++ itkIsolatedConnectedImageFilterIUC3IUC3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkIsolatedConnectedImageFilterIUC3IUC3_Pointer"""
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIUC3IUC3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkIsolatedConnectedImageFilterIUC3IUC3_Pointer"""
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIUC3IUC3_Clone(self)

    def PrintSelf(self, os, indent):
        r"""
        PrintSelf(self, os, indent)

        Parameters
        ----------
        os: std::basic_ostream< char,std::char_traits< char > > &
        indent: itkIndent

        """
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIUC3IUC3_PrintSelf(self, os, indent)

    def AddSeed1(self, seed):
        r"""
        AddSeed1(self, seed)

        Parameters
        ----------
        seed: itkIndex3 const &

        """
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIUC3IUC3_AddSeed1(self, seed)

    def SetSeed1(self, seed):
        r"""
        SetSeed1(self, seed)

        Parameters
        ----------
        seed: itkIndex3 const &

        """
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIUC3IUC3_SetSeed1(self, seed)

    def ClearSeeds1(self):
        r"""ClearSeeds1(self)"""
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIUC3IUC3_ClearSeeds1(self)

    def AddSeed2(self, seed):
        r"""
        AddSeed2(self, seed)

        Parameters
        ----------
        seed: itkIndex3 const &

        """
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIUC3IUC3_AddSeed2(self, seed)

    def SetSeed2(self, seed):
        r"""
        SetSeed2(self, seed)

        Parameters
        ----------
        seed: itkIndex3 const &

        """
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIUC3IUC3_SetSeed2(self, seed)

    def ClearSeeds2(self):
        r"""ClearSeeds2(self)"""
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIUC3IUC3_ClearSeeds2(self)

    def GetSeeds1(self):
        r"""GetSeeds1(self) -> std::vector< itkIndex3,std::allocator< itkIndex3 > > const &"""
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIUC3IUC3_GetSeeds1(self)

    def GetSeeds2(self):
        r"""GetSeeds2(self) -> std::vector< itkIndex3,std::allocator< itkIndex3 > > const &"""
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIUC3IUC3_GetSeeds2(self)

    def SetLower(self, _arg):
        r"""
        SetLower(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIUC3IUC3_SetLower(self, _arg)

    def GetLower(self):
        r"""GetLower(self) -> unsigned char const &"""
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIUC3IUC3_GetLower(self)

    def SetUpper(self, _arg):
        r"""
        SetUpper(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIUC3IUC3_SetUpper(self, _arg)

    def GetUpper(self):
        r"""GetUpper(self) -> unsigned char const &"""
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIUC3IUC3_GetUpper(self)

    def SetIsolatedValueTolerance(self, _arg):
        r"""
        SetIsolatedValueTolerance(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIUC3IUC3_SetIsolatedValueTolerance(self, _arg)

    def GetIsolatedValueTolerance(self):
        r"""GetIsolatedValueTolerance(self) -> unsigned char const &"""
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIUC3IUC3_GetIsolatedValueTolerance(self)

    def SetReplaceValue(self, _arg):
        r"""
        SetReplaceValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIUC3IUC3_SetReplaceValue(self, _arg)

    def GetReplaceValue(self):
        r"""GetReplaceValue(self) -> unsigned char const &"""
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIUC3IUC3_GetReplaceValue(self)

    def GetIsolatedValue(self):
        r"""GetIsolatedValue(self) -> unsigned char const &"""
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIUC3IUC3_GetIsolatedValue(self)

    def SetFindUpperThreshold(self, _arg):
        r"""
        SetFindUpperThreshold(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIUC3IUC3_SetFindUpperThreshold(self, _arg)

    def FindUpperThresholdOn(self):
        r"""FindUpperThresholdOn(self)"""
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIUC3IUC3_FindUpperThresholdOn(self)

    def FindUpperThresholdOff(self):
        r"""FindUpperThresholdOff(self)"""
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIUC3IUC3_FindUpperThresholdOff(self)

    def GetFindUpperThreshold(self):
        r"""GetFindUpperThreshold(self) -> bool const &"""
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIUC3IUC3_GetFindUpperThreshold(self)

    def GetThresholdingFailed(self):
        r"""GetThresholdingFailed(self) -> bool const &"""
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIUC3IUC3_GetThresholdingFailed(self)
    InputHasNumericTraitsCheck = _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIUC3IUC3_InputHasNumericTraitsCheck
    
    __swig_destroy__ = _itkIsolatedConnectedImageFilterPython.delete_itkIsolatedConnectedImageFilterIUC3IUC3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkIsolatedConnectedImageFilterIUC3IUC3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIUC3IUC3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkIsolatedConnectedImageFilterIUC3IUC3

        Create a new object of the class itkIsolatedConnectedImageFilterIUC3IUC3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkIsolatedConnectedImageFilterIUC3IUC3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkIsolatedConnectedImageFilterIUC3IUC3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkIsolatedConnectedImageFilterIUC3IUC3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkIsolatedConnectedImageFilterIUC3IUC3 in _itkIsolatedConnectedImageFilterPython:
_itkIsolatedConnectedImageFilterPython.itkIsolatedConnectedImageFilterIUC3IUC3_swigregister(itkIsolatedConnectedImageFilterIUC3IUC3)

from itk.support import helpers
import itk.support.types as itkt
from typing import Sequence, Tuple, Union

@helpers.accept_array_like_xarray_torch
def isolated_connected_image_filter(*args: itkt.ImageLike,  seed1: Sequence[int]=..., seed2: Sequence[int]=..., lower: int=..., upper: int=..., isolated_value_tolerance: int=..., replace_value: int=..., find_upper_threshold: bool=...,**kwargs)-> itkt.ImageSourceReturn:
    """Functional interface for IsolatedConnectedImageFilter"""
    import itk

    kwarg_typehints = { 'seed1':seed1,'seed2':seed2,'lower':lower,'upper':upper,'isolated_value_tolerance':isolated_value_tolerance,'replace_value':replace_value,'find_upper_threshold':find_upper_threshold }
    specified_kwarg_typehints = { k:v for (k,v) in kwarg_typehints.items() if kwarg_typehints[k] is not ... }
    kwargs.update(specified_kwarg_typehints)


    instance = itk.IsolatedConnectedImageFilter.New(*args, **kwargs)

    return instance.__internal_call__()

def isolated_connected_image_filter_init_docstring():
    import itk
    from itk.support import template_class

    filter_class = itk.ITKRegionGrowing.IsolatedConnectedImageFilter
    isolated_connected_image_filter.process_object = filter_class
    is_template = isinstance(filter_class, template_class.itkTemplate)
    if is_template:
        filter_object = filter_class.values()[0]
    else:
        filter_object = filter_class

    isolated_connected_image_filter.__doc__ = filter_object.__doc__



